module.exports = defineTest({
	description: 'supports core-js feature detection (#2869)'
});
